# outputs.tf defines outputs for the module.

output "service" {
  description = "Webapp Cloud Run service resource"
  value       = google_cloud_run_service.webapp
}

output "service_account" {
  description = "Service account which service runs as"
  value       = google_service_account.webapp
}

output "load_balancer" {
  description = "Load balancer for the webapp"
  value       = module.webapp_http_load_balancer
}

output "domain_mapping_present" {
  description = "Flag indicating if a domain mapping is present for the webapp"
  value       = local.domain_mapping_present
}

output "domain_mapping_resource_record" {
  value       = try(local.dns_records[0], {})
  description = <<EOI
    Deprecated. Use dns_resource_records output instead.

    Resource record for DNS hostnames. If a domain mapping or load balancing is configured
    the following keys will be set: type and rrdata. If no mapping is configured, the
    map will be empty.
  EOI
}

output "dns_resource_records" {
  value       = local.dns_records
  description = <<EOI
    List of DNS records for web application. Each element is an object with "type" and "rrdata"
    keys.
  EOI
}

output "domain_mapping_dns_name" {
  description = <<EOI
DNS name (minus trailing dot) of webapp. Will be blank if no DNS name
configured.
EOI
  value       = var.dns_name
}

output "static_egress_ip" {
  description = <<EOI
The static egress IP assigned to this cloud run instance. Only populated
if the variable `enable_static_egress_ip` is true.
EOI
  value       = var.enable_static_egress_ip ? google_compute_address.static-ip[0].address : ""
}
